/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Sven Jacobi <sven.jacobi@open-xchange.com>
 */

define('io.ox/office/presentation/main', [
    'io.ox/office/baseframework/app/applicationlauncher'
], function (ApplicationLauncher) {

    'use strict';

    // entry point for the OX AppSuite front-end to launch a new OX Presentation instance
    return ApplicationLauncher.createLauncher('io.ox/office/presentation', {
        icon: 'fa-film',
        trackingId: 'io.ox/presentation-editor'
    });

});
